aboutsummaryrefslogtreecommitdiff
path: root/include/libssh/sftp.h
diff options
context:
space:
mode:
authorAris Adamantiadis <aris@0xbadc0de.be>2009-09-29 17:52:09 +0200
committerAris Adamantiadis <aris@0xbadc0de.be>2009-09-29 17:57:37 +0200
commitf6f0988d10ade62e053aadca1aec2bf57edf30f9 (patch)
treec8c68d2d4f613337142fe9dcab67f87d7e1db339 /include/libssh/sftp.h
parentf9d1542542b652c36fbc180214f44fd242ae53cf (diff)
downloadlibssh-f6f0988d10ade62e053aadca1aec2bf57edf30f9.tar.gz
libssh-f6f0988d10ade62e053aadca1aec2bf57edf30f9.tar.xz
libssh-f6f0988d10ade62e053aadca1aec2bf57edf30f9.zip
Fix warnings on opensolaris
Diffstat (limited to 'include/libssh/sftp.h')
-rw-r--r--include/libssh/sftp.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/libssh/sftp.h b/include/libssh/sftp.h
index 1c4a2ab5..68c0788e 100644
--- a/include/libssh/sftp.h
+++ b/include/libssh/sftp.h
@@ -399,7 +399,7 @@ LIBSSH_API int sftp_file_close(SFTP_FILE *file) SFTP_DEPRECATED;
*
* @param file The file to be opened.
*
* @param access Is one of O_RDONLY, O_WRONLY or O_RDWR which request
* opening the file read-only,write-only or read/write.
* Acesss may also be bitwise-or'd with one or more of
* the following:
@@ -418,7 +418,7 @@ LIBSSH_API int sftp_file_close(SFTP_FILE *file) SFTP_DEPRECATED;
* @return A sftp file handle, NULL on error with ssh and sftp
* error set.
*/
-LIBSSH_API SFTP_FILE *sftp_open(SFTP_SESSION *session, const char *file, int access,
+LIBSSH_API SFTP_FILE *sftp_open(SFTP_SESSION *session, const char *file, int accesstype,
mode_t mode);
LIBSSH_API void sftp_file_set_nonblocking(SFTP_FILE *handle);
@@ -730,9 +730,9 @@ LIBSSH_API SFTP_STATVFS *sftp_fstatvfs(SFTP_FILE *file);
/**
* @brief Free the memory of an allocated statvfs.
*
* @param statvfs The statvfs to free.
*/
-LIBSSH_API void sftp_statvfs_free(SFTP_STATVFS *statvfs);
+LIBSSH_API void sftp_statvfs_free(SFTP_STATVFS *statvfs_o);
/**
* @brief Canonicalize a sftp path.
@@ -399,7 +399,7 @@ LIBSSH_API int sftp_file_close(SFTP_FILE *file) SFTP_DEPRECATED;
* @param file The file to be opened.
*
- * @param access Is one of O_RDONLY, O_WRONLY or O_RDWR which request
+ * @param accesstype Is one of O_RDONLY, O_WRONLY or O_RDWR which request
* opening the file read-only,write-only or read/write.
* Acesss may also be bitwise-or'd with one or more of
@@ -730,9 +730,9 @@ LIBSSH_API SFTP_STATVFS *sftp_fstatvfs(SFTP_FILE *file);
* @brief Free the memory of an allocated statvfs.
*
- * @param statvfs The statvfs to free.
+ * @param statvfs_o The statvfs to free.
*/